Module data

Module data 

Enums

DataParameter
Parameter types for data queries.
Detail
Using the detail parameter, it is possible to specify the desired amount of information to be returned by the web service.
Format
PeriodFormat