pub enum DataParameter<Tz>{
StartPeriod {
datetime: DateTime<Tz>,
period_format: PeriodFormat,
},
EndPeriod {
datetime: DateTime<Tz>,
period_format: PeriodFormat,
},
UpdatedAfter {
datetime: DateTime<Tz>,
},
Detail {
detail: Detail,
},
FirstNObservations {
n: usize,
},
LastNObservations {
n: usize,
},
IncludeHistory {
yes: bool,
},
Format {
format: Format,
},
}Expand description
Parameter types for data queries.
Variants
StartPeriod
It is possible to define a date range for which Observations are to be returned by using the startPeriod and/or endPeriod parameters.
EndPeriod
It is possible to define a date range for which Observations are to be returned by using the startPeriod and/or endPeriod parameters.
UpdatedAfter
By supplying a percent-encoded ISO 8601 timestamp for the updatedAfter parameter, it is possible to retrieve the latest version of changed values in the database after a certain point in time (i.e., updates and revisions). This will include:
- The Observations that have been added since the supplied timestamp
- TYhe Observations that have been revised since the supplied timestamp
- The Observations that have been deleted since the supplied timestamp
Detail
Using the detail parameter, it is possible to specify the desired amount of information to be returned by the web service.
FirstNObservations
Using the firstNObservations parameter, it is possible to specify the maximum number of Observations to be returned for each of the matching Time series, starting from the first Observation (firstNObservations).
LastNObservations
Using the lastNObservations parameter, it is possible to specify the maximum number of Observations to be returned for each of the matching Time series, counting back from the most recent Observation (lastNObservations).
IncludeHistory
Using the includeHistory parameter, you can instruct the web service to return previous versions of the matching data. This allows you to see how the data have evolved over time (i.e., see when new data were released, revised or deleted). Possible options are:
false: Only the version currently in production will be returned. This is the default.true: The version currently in production and all previous versions will be returned.
Format
Using the format parameter, you can instruct the web service to return data in different formats.