pub enum Detail {
Full,
DataOnly,
SeriesKeysOnly,
NoData,
}Expand description
Using the detail parameter, it is possible to specify the desired amount of information to be returned by the web service.
Variants
Full
The data (Time series and Observations) and the Attributes will be returned. This is the default.
DataOnly
The Attributes will be excluded from the returned message.
SeriesKeysOnly
Only the Time series will be returned, excluding the Attributes and the Observations. This can be used to list Time series that match a certain query without returning the actual data.
NoData
The Time series will be returned, including the Attributes, but the Observations will not.