pub enum Detail {
Full,
AllStubs,
ReferenceStubs,
}Expand description
Using the detail parameter, you can specify the desired amount of information to be returned. For example, it is possible to instruct the web service to return only basic information about the resource (i.e., its id, agency id, version and name. This is also known as a stub in SDMX).
Variants
Full
All available information for all artefacts will be returned. This is the default.
AllStubs
All artefacts will be returned as stubs
ReferenceStubs
The referenced artefacts will be returned as stubs