pub enum MetadataParameter {
Detail {
detail: Detail,
},
References {
references: References,
},
}Expand description
Parameter types for metadata queries.
Variants
Detail
Using the detail parameter, you can specify the desired amount of information to be returned. For example, it is possible to instruct the web service to return only basic information about the resource (i.e., its id, agency id, version and name. This is also known as a stub in SDMX).
References
Using the references parameter, you can instruct the web service to return (or exclude) the artefacts that use or are referenced by the artefact matching the query. This includes, for example, the codelists and Concepts used by the DSD matching the query. You can also retrieve the artefacts that use the matching artefact, such as the Dataflows that use the DSD matching the query.
Fields

references: ReferencesTrait Implementations
Sourceimpl Clone for MetadataParameter
impl Clone for MetadataParameter
Sourcefn clone(&self) -> MetadataParameter
fn clone(&self) -> MetadataParameter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataParameter
impl Debug for MetadataParameter