Context

Enum Context 

pub enum Context {
    DataStructure,
    DataFlow,
    ProvisionAgreement,
}
The context determines the constraints that need to be taken into account when generating the schema.

Variants



DataStructure

Constraints attached to the DSD will be used in the schema



DataFlow

Constraints attached to the Dataflow and to the DSD referenced by the Dataflow will be used in the schema



ProvisionAgreement

Constraints attached to the provision agreement, the Dataflow referenced by the agreement and to the DSD referenced by the Dataflow will be available in the schema