FlowRef

Struct FlowRef 

pub struct FlowRef {
    pub agency_id: Option<String>,
    pub flow_id: String,
    pub version: Option<String>,
}
FlowRef (Defining the dataflow reference)

A reference to the dataflow describing the data that needs to be returned. The syntax is the identifier of the agency maintaining the dataflow, followed by the identifier of the dataflow, followed by the dataflow version, separated by a comma (,). For example: AGENCY_ID,FLOW_ID,VERSION

If the parameter contains only one of these three elements, it is considered to be the identifier of the dataflow. The value for the identifier of the agency maintaining the dataflow will default to all, while the value for the dataflow version will default to latest.

If the string contains only two of these three elements, they are the identifier of the agency maintaining the dataflow and the identifier of the dataflow. The value for the dataflow version will default to latest.

In order to see the dataflows available in the ECB Data Portal, a metadata query for all dataflows can be performed:

Fields

agency_id: Option<String>

The identifier of the maintainer of the context

flow_id: String

The identifier of the context, such as EXR for the Dataflow about exchange rates maintained by the ECB

Note: On the ECB Data Portal the series are prefixed with their flow identifier. For example, EXR.M.USD.EUR.SP00.A is the series key on the ECB Data Portal, but EXR is an flow_id and M.USD.EUR.SP00.A is the series_key in this implementation.

version: Option<String>

The version of the context to be returned. When the version number is not supplied, the latest version is returned