Module time

Module time 

Module with time conversion utilities for ECB Data Portal.

The utilities defined here convert between the formats used by the ECB and chrono library. The timezones in chrono are assumed to be FixedOffset.

Functions

datetime_to_ecb_period
Converts a DateTime object into an ECB Data Portal formatted period.
ecb_string_to_datetime
Converts an ECB Data Portal formatted datetime into a DateTime object.
percent_encode_datetime
Percent econdes datetime string to be included in a URL.