Module data
ecbdp_
api
0.1.1
Module data
Module Items
Enums
In ecbdp_
api::
parameter
ecbdp_api
::
parameter
Module
data
Enums

Data
Parameter
Parameter types for
data
queries.
Detail
Using the detail parameter, it is possible to specify the desired amount of information to be returned by the web service.
Format
Period
Format