References

Enum References 

pub enum References {
    None,
    Parents,
    ParentsAndSiblings,
    Children,
    Descendants,
    All,
}
Using the references parameter, you can instruct the web service to return (or exclude) the artefacts that use or are referenced by the artefact matching the query. This includes, for example, the codelists and Concepts used by the DSD matching the query. You can also retrieve the artefacts that use the matching artefact, such as the Dataflows that use the DSD matching the query.

Variants



None

No references will be returned. This is the default.



Parents

The artefacts that use the artefact matching the query (for example, the Dataflows that use the DSD matching the query) will be returned



ParentsAndSiblings

The artefacts that use the artefact matching the query, as well as the artefacts referenced by these artefacts, will be returned



Children

The artefacts referenced by the matching artefact (for example, the Concept schemes and codelists used in a DSD) will be returned



Descendants

References of references, up to any level, will also be returned



All

The combination of ParentsAndSiblings and Descendants